@@ -19,39 +19,44 @@
 
 typedef struct OgrDeparseCtx
 {
-	PlannerInfo *root;        /* global planner state */
-	RelOptInfo *foreignrel;   /* the foreign relation we are planning for */
+	PlannerInfo* root;        /* global planner state */
+	RelOptInfo* foreignrel;   /* the foreign relation we are planning for */
 	StringInfo buf;           /* output buffer to append to */
-	List **params_list;       /* exprs that will become remote Params */
+	List** params_list;       /* exprs that will become remote Params */
 	OGRGeometryH geom;        /* if filter contains a geometry constant, it resides here */
-	OgrFdwState *state;       /* to convert local column names to OGR names */
+	OgrFdwState* state;       /* to convert local column names to OGR names */
 } OgrDeparseCtx;
 
 /* Local function signatures */
-static bool ogrDeparseExpr(Expr *node, OgrDeparseCtx *context);
+static bool ogrDeparseExpr(Expr* node, OgrDeparseCtx* context);
 // static void ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx *context);
 
-static void setStringInfoLength(StringInfo str, int len)
+static void
+setStringInfoLength(StringInfo str, int len)
 {
 	str->len = len;
 	str->data[len] = '\0';
 }
 
-static char *
+static char*
 ogrStringFromDatum(Datum datum, Oid type)
 {
 	StringInfoData result;
 	regproc typoutput;
 	HeapTuple tuple;
-	char *str, *p;
+	char* str, *p;
 
 	/* Special handling for boolean */
-	if ( type == BOOLOID )
+	if (type == BOOLOID)
 	{
-		if ( datum )
+		if (datum)
+		{
 			return "1=1";
+		}
 		else
+		{
 			return "1=0";
+		}
 	}
 
 	/* get the type's output function */
@@ -66,7 +71,7 @@ ogrStringFromDatum(Datum datum, Oid type)
 	initStringInfo(&result);
 
 	/* Special handling to convert a geometry to a bbox needed here */
-	if ( type == ogrGetGeometryOid() )
+	if (type == ogrGetGeometryOid())
 	{
 		elog(ERROR, "got a GEOMETRY!");
 		return NULL;
@@ -75,50 +80,54 @@ ogrStringFromDatum(Datum datum, Oid type)
 	/* render the constant in OGR SQL */
 	switch (type)
 	{
-		case TEXTOID:
-		case DATEOID:
-		case TIMESTAMPOID:
-		case TIMESTAMPTZOID:
-		case CHAROID:
-		case BPCHAROID:
-		case VARCHAROID:
-		case NAMEOID:
-			str = DatumGetCString(OidFunctionCall1(typoutput, datum));
+	case TEXTOID:
+	case DATEOID:
+	case TIMESTAMPOID:
+	case TIMESTAMPTZOID:
+	case CHAROID:
+	case BPCHAROID:
+	case VARCHAROID:
+	case NAMEOID:
+		str = DatumGetCString(OidFunctionCall1(typoutput, datum));
 
-			/* Don't return a zero length string, return an empty string */
-			if (str[0] == '\0')
-				return "''";
+		/* Don't return a zero length string, return an empty string */
+		if (str[0] == '\0')
+		{
+			return "''";
+		}
 
-			/* wrap string with ' */
-			appendStringInfoChar(&result, '\'');
-			for (p=str; *p; ++p)
+		/* wrap string with ' */
+		appendStringInfoChar(&result, '\'');
+		for (p = str; *p; ++p)
+		{
+			/* Escape single quotes as doubled '' */
+			if (*p == '\'')
 			{
-				/* Escape single quotes as doubled '' */
-				if (*p == '\'')
-					appendStringInfoChar(&result, '\'');
-				appendStringInfoChar(&result, *p);
+				appendStringInfoChar(&result, '\'');
 			}
-			appendStringInfoChar(&result, '\'');
-			break;
-		case INT8OID:
-		case INT2OID:
-		case INT4OID:
-		case OIDOID:
-		case FLOAT4OID:
-		case FLOAT8OID:
-		case NUMERICOID:
-			appendStringInfoString(&result, DatumGetCString(OidFunctionCall1(typoutput, datum)));
-			break;
-		default:
-			elog(DEBUG1, "could not convert type (%d) to OGR query form", type);
-			return NULL;
+			appendStringInfoChar(&result, *p);
+		}
+		appendStringInfoChar(&result, '\'');
+		break;
+	case INT8OID:
+	case INT2OID:
+	case INT4OID:
+	case OIDOID:
+	case FLOAT4OID:
+	case FLOAT8OID:
+	case NUMERICOID:
+		appendStringInfoString(&result, DatumGetCString(OidFunctionCall1(typoutput, datum)));
+		break;
+	default:
+		elog(DEBUG1, "could not convert type (%d) to OGR query form", type);
+		return NULL;
 	}
 
 	return result.data;
 }
 
 static bool
-ogrDeparseConst(Const* constant, OgrDeparseCtx *context)
+ogrDeparseConst(Const* constant, OgrDeparseCtx* context)
 {
 	/* TODO: Can OGR do anythign w/ NULL? */
 	if (constant->constisnull)
@@ -126,7 +135,7 @@ ogrDeparseConst(Const* constant, OgrDeparseCtx *context)
 		appendStringInfoString(context->buf, "NULL");
 	}
 	/* Use geometry as a spatial filter? */
-	else if ( constant->consttype == ogrGetGeometryOid() )
+	else if (constant->consttype == ogrGetGeometryOid())
 	{
 		/*
 		 * For geometry we need to convert the gserialized constant into
@@ -137,8 +146,8 @@ ogrDeparseConst(Const* constant, OgrDeparseCtx *context)
 		Oid sendfunction;
 		bool typeIsVarlena;
 		Datum wkbdatum;
-		char *gser;
-		char *wkb;
+		char* gser;
+		char* wkb;
 		int wkb_size;
 		OGRGeometryH ogrgeom;
 		OGRErr err;
@@ -157,17 +166,21 @@ ogrDeparseConst(Const* constant, OgrDeparseCtx *context)
 		gser = DatumGetPointer(wkbdatum);
 		wkb = VARDATA(gser);
 		wkb_size = VARSIZE(gser) - VARHDRSZ;
-		err = OGR_G_CreateFromWkb((unsigned char *)wkb, NULL, &ogrgeom, wkb_size);
+		err = OGR_G_CreateFromWkb((unsigned char*)wkb, NULL, &ogrgeom, wkb_size);
 
 		/*
 		 * Save the result
 		 */
-		if ( err != OGRERR_NONE )
+		if (err != OGRERR_NONE)
 		{
-			if ( ! context->geom )
+			if (! context->geom)
+			{
 				context->geom = ogrgeom;
+			}
 			else
+			{
 				elog(WARNING, "got two geometries in OGR FDW query, only using the first");
+			}
 		}
 		/*
 		 * geometry doesn't play a role in the deparsed SQL
@@ -177,8 +190,8 @@ ogrDeparseConst(Const* constant, OgrDeparseCtx *context)
 	else
 	{
 		/* get a string representation of the value */
-		char *c = ogrStringFromDatum(constant->constvalue, constant->consttype);
-		if ( c == NULL )
+		char* c = ogrStringFromDatum(constant->constvalue, constant->consttype);
+		if (c == NULL)
 		{
 			return false;
 		}
@@ -192,44 +205,48 @@ ogrDeparseConst(Const* constant, OgrDeparseCtx *context)
 
 
 static bool
-ogrDeparseParam(Param *node, OgrDeparseCtx *context)
+ogrDeparseParam(Param* node, OgrDeparseCtx* context)
 {
 	elog(DEBUG3, "got into ogrDeparseParam code");
 	return false;
 }
 
 static bool
-ogrIsLegalVarName(const char *varname)
+ogrIsLegalVarName(const char* varname)
 {
 	size_t len = strlen(varname);
 	int i;
 
-	for ( i = 0; i < len; i++ )
+	for (i = 0; i < len; i++)
 	{
 		char c = varname[i];
 
 		/* First char must be a-zA-Z */
-		if ( i == 0 && ! ((c>=97&&c<=122)||(c>=65&&c<=90)) )
+		if (i == 0 && !((c >= 97 && c <= 122) || (c >= 65 && c <= 90)))
+		{
 			return false;
+		}
 
 		/* All other chars must be 0-9a-zA-Z_ */
-		if ( ! ((c>=97&&c<=122)||(c>=65&&c<=90)||(c>=48&&c<=59)||(c==96)) )
+		if (!((c >= 97 && c <= 122) || (c >= 65 && c <= 90) || (c >= 48 && c <= 59) || (c == 96)))
+		{
 			return false;
+		}
 
 	}
 	return true;
 }
 
 static bool
-ogrDeparseVar(Var *node, OgrDeparseCtx *context)
+ogrDeparseVar(Var* node, OgrDeparseCtx* context)
 {
-	StringInfoData *buf = context->buf;
+	StringInfoData* buf = context->buf;
 
 	if (node->varno == context->foreignrel->relid && node->varlevelsup == 0)
 	{
 		/* Var belongs to foreign table */
 		int i;
-		OgrFdwTable *table = context->state->table;
+		OgrFdwTable* table = context->state->table;
 		OGRLayerH lyr = context->state->ogr.lyr;
 		bool done = false;
 
@@ -239,31 +256,37 @@ ogrDeparseVar(Var *node, OgrDeparseCtx *context)
 		/* TODO: Handle case of mapping columns to OGR columns that don't share their name */
 		/* TODO: Lookup OGR column name by going from varattno -> OGR via a table/OGR map */
 
-		for ( i = 0; i < table->ncols; i++ )
+		for (i = 0; i < table->ncols; i++)
 		{
-			if ( table->cols[i].pgattnum == node->varattno )
+			if (table->cols[i].pgattnum == node->varattno)
 			{
-				const char *fldname = NULL;
+				const char* fldname = NULL;
 
-				if ( table->cols[i].ogrvariant == OGR_FID )
+				if (table->cols[i].ogrvariant == OGR_FID)
 				{
 					fldname = OGR_L_GetFIDColumn(lyr);
-					if ( ! fldname || strlen(fldname) == 0 )
+					if (! fldname || strlen(fldname) == 0)
+					{
 						fldname = "fid";
+					}
 				}
-				else if ( table->cols[i].ogrvariant == OGR_FIELD )
+				else if (table->cols[i].ogrvariant == OGR_FIELD)
 				{
 					OGRFeatureDefnH fd = OGR_L_GetLayerDefn(lyr);
 					OGRFieldDefnH fld = OGR_FD_GetFieldDefn(fd, table->cols[i].ogrfldnum);
 					fldname = OGR_Fld_GetNameRef(fld);
 				}
 
-				if ( fldname )
+				if (fldname)
 				{
-					if ( ogrIsLegalVarName(fldname) )
+					if (ogrIsLegalVarName(fldname))
+					{
 						appendStringInfoString(buf, fldname);
+					}
 					else
+					{
 						appendStringInfo(buf, "\"%s\"", fldname);
+					}
 
 					done = true;
 				}
@@ -281,48 +304,55 @@ ogrDeparseVar(Var *node, OgrDeparseCtx *context)
 	return true;
 }
 
-static int ogrOperatorCmpFunc(const void * a, const void * b)
+static int
+ogrOperatorCmpFunc(const void* a, const void* b)
 {
 	return strcasecmp(*(const char**)a, *(const char**)b);
 }
 
 static bool
-ogrOperatorIsSupported(const char *opname)
+ogrOperatorIsSupported(const char* opname)
 {
 	/* IMPORTANT */
 	/* This array MUST be in sorted order or the bsearch will fail */
-	static const char * ogrOperators[10] = { "!=", "&&", "<", "<=", "<>", "=", ">", ">=", "~~", "~~*" };
+	static const char* ogrOperators[10] = { "!=", "&&", "<", "<=", "<>", "=", ">", ">=", "~~", "~~*" };
 
 	elog(DEBUG3, "ogrOperatorIsSupported got operator '%s'", opname);
 
-	if ( bsearch(&opname, ogrOperators, 10, sizeof(char*), ogrOperatorCmpFunc) )
+	if (bsearch(&opname, ogrOperators, 10, sizeof(char*), ogrOperatorCmpFunc))
+	{
 		return true;
+	}
 	else
+	{
 		return false;
+	}
 }
 
 
 static bool
-ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx *context)
+ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx* context)
 {
 	StringInfo buf = context->buf;
 	HeapTuple tuple;
 	Form_pg_operator form;
 	char oprkind;
-	char *opname;
-	ListCell *arg;
+	char* opname;
+	ListCell* arg;
 	bool result = true;
 
 	/* Retrieve information about the operator from system catalog. */
 	tuple = SearchSysCache1(OPEROID, ObjectIdGetDatum(node->opno));
 	if (!HeapTupleIsValid(tuple))
+	{
 		elog(ERROR, "cache lookup failed for operator %u", node->opno);
+	}
 	form = (Form_pg_operator) GETSTRUCT(tuple);
 	oprkind = form->oprkind;
 	opname = NameStr(form->oprname);
 
 	/* Don't deparse expressions we cannot support */
-	if ( ! ogrOperatorIsSupported(opname) )
+	if (! ogrOperatorIsSupported(opname))
 	{
 		ReleaseSysCache(tuple);
 		return false;
@@ -333,7 +363,7 @@ ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx *context)
 
 	/* Overlaps operator is special case: if one side is a constant, */
 	/* then we can pass it as a spatial filter to OGR */
-	if ( strcmp("&&", opname) == 0 )
+	if (strcmp("&&", opname) == 0)
 	{
 		// Expr *r_arg = lfirst(list_head(node->args));
 		// Expr *l_arg = lfirst(list_tail(node->args));
@@ -369,7 +399,7 @@ ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx *context)
 	appendStringInfoChar(buf, '(');
 
 	/* Deparse left operand. */
-	if ( oprkind == 'r' || oprkind == 'b' )
+	if (oprkind == 'r' || oprkind == 'b')
 	{
 		arg = list_head(node->args);
 		/* recurse for nested operations */
@@ -381,8 +411,10 @@ ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx *context)
 	/* by PgSQL, so we have to convert it back here */
 	/* All OGR string comparisons are case insensitive, so we just */
 	/* use 'ILIKE' all the time. */
-	if ( streq(opname, "~~") || streq(opname, "~~*") )
+	if (streq(opname, "~~") || streq(opname, "~~*"))
+	{
 		opname = "ILIKE";
+	}
 
 	/* Operator symbol */
 	appendStringInfoString(buf, opname);
@@ -404,10 +436,10 @@ ogrDeparseOpExpr(OpExpr* node, OgrDeparseCtx *context)
 }
 
 static bool
-ogrDeparseBoolExpr(BoolExpr *node, OgrDeparseCtx *context)
+ogrDeparseBoolExpr(BoolExpr* node, OgrDeparseCtx* context)
 {
-	const char *op = NULL;		/* keep compiler quiet */
-	ListCell *lc;
+	const char* op = NULL;		/* keep compiler quiet */
+	ListCell* lc;
 	bool first = true;
 	bool result = true;
 	int len_save_all, len_save_part;
@@ -417,144 +449,164 @@ ogrDeparseBoolExpr(BoolExpr *node, OgrDeparseCtx *context)
 
 	switch (boolop)
 	{
-		case AND_EXPR:
-			op = "AND";
-			break;
-		case OR_EXPR:
-			op = "OR";
-			break;
+	case AND_EXPR:
+		op = "AND";
+		break;
+	case OR_EXPR:
+		op = "OR";
+		break;
 
-		/* OGR SQL cannot handle "NOT" */
-		case NOT_EXPR:
-			return false;
+	/* OGR SQL cannot handle "NOT" */
+	case NOT_EXPR:
+		return false;
 	}
 
 	len_save_all = buf->len;
 
 	appendStringInfoChar(buf, '(');
-	foreach(lc, node->args)
+	foreach (lc, node->args)
 	{
 
 		len_save_part = buf->len;
 
 		/* Connect expressions and parenthesize each condition */
-		if ( ! first )
+		if (! first)
+		{
 			appendStringInfo(buf, " %s ", op);
+		}
 
 		/* Unparse the expression, if possible */
-		result = ogrDeparseExpr((Expr *) lfirst(lc), context);
+		result = ogrDeparseExpr((Expr*) lfirst(lc), context);
 		result_total += result;
 
 		/* We can backtrack just this term for AND expressions */
-		if ( boolop == AND_EXPR && ! result )
+		if (boolop == AND_EXPR && ! result)
+		{
 			setStringInfoLength(buf, len_save_part);
+		}
 
 		/* We have to drop the whole thing if we can't get every part of an OR expression */
-		if ( boolop == OR_EXPR && ! result )
+		if (boolop == OR_EXPR && ! result)
+		{
 			break;
+		}
 
 		/* Don't flip the "first" bit until we get a good expression */
-		if ( first && result )
+		if (first && result)
+		{
 			first = false;
+		}
 	}
 	appendStringInfoChar(buf, ')');
 
 	/* We have to drop the whole thing if we can't get every part of an OR expression */
-	if ( boolop == OR_EXPR && ! result )
+	if (boolop == OR_EXPR && ! result)
+	{
 		setStringInfoLength(buf, len_save_all);
+	}
 
 	return result_total > 0;
 }
 
 
 static bool
-ogrDeparseRelabelType(RelabelType *node, OgrDeparseCtx *context)
+ogrDeparseRelabelType(RelabelType* node, OgrDeparseCtx* context)
 {
 	if (node->relabelformat != COERCE_IMPLICIT_CAST)
+	{
 		elog(WARNING, "Received a non-implicit relabel expression but did not handle it");
+	}
 
 	return ogrDeparseExpr(node->arg, context);
 }
 
 static bool
-ogrDeparseNullTest(NullTest *node, OgrDeparseCtx *context)
+ogrDeparseNullTest(NullTest* node, OgrDeparseCtx* context)
 {
 	StringInfo buf = context->buf;
 
 	appendStringInfoChar(buf, '(');
 	ogrDeparseExpr(node->arg, context);
 	if (node->nulltesttype == IS_NULL)
+	{
 		appendStringInfoString(buf, " IS NULL)");
+	}
 	else
+	{
 		appendStringInfoString(buf, " IS NOT NULL)");
+	}
 
 	return true;
 }
 
 static bool
-ogrDeparseExpr(Expr *node, OgrDeparseCtx *context)
+ogrDeparseExpr(Expr* node, OgrDeparseCtx* context)
 {
-	if ( node == NULL )
-		return false;
-
-	switch ( nodeTag(node) )
+	if (node == NULL)
 	{
-		case T_OpExpr:
-			return ogrDeparseOpExpr((OpExpr *) node, context);
-		case T_Const:
-			return ogrDeparseConst((Const *) node, context);
-		case T_Var:
-			return ogrDeparseVar((Var *) node, context);
-		case T_Param:
-			return ogrDeparseParam((Param *) node, context);
-		case T_BoolExpr:
-			/* Handle "OR" and "NOT" queries */
-			return ogrDeparseBoolExpr((BoolExpr *) node, context);
-		case T_NullTest:
-			/* Handle "IS NULL" queries */
-			return ogrDeparseNullTest((NullTest *) node, context);
-		case T_RelabelType:
-			return ogrDeparseRelabelType((RelabelType *) node, context);
-		case T_ScalarArrayOpExpr:
-			/* TODO: Handle this to support the "IN" operator */
-			elog(NOTICE, "unsupported OGR FDW expression type, T_ScalarArrayOpExpr");
-			return false;
+		return false;
+	}
+
+	switch (nodeTag(node))
+	{
+	case T_OpExpr:
+		return ogrDeparseOpExpr((OpExpr*) node, context);
+	case T_Const:
+		return ogrDeparseConst((Const*) node, context);
+	case T_Var:
+		return ogrDeparseVar((Var*) node, context);
+	case T_Param:
+		return ogrDeparseParam((Param*) node, context);
+	case T_BoolExpr:
+		/* Handle "OR" and "NOT" queries */
+		return ogrDeparseBoolExpr((BoolExpr*) node, context);
+	case T_NullTest:
+		/* Handle "IS NULL" queries */
+		return ogrDeparseNullTest((NullTest*) node, context);
+	case T_RelabelType:
+		return ogrDeparseRelabelType((RelabelType*) node, context);
+	case T_ScalarArrayOpExpr:
+		/* TODO: Handle this to support the "IN" operator */
+		elog(NOTICE, "unsupported OGR FDW expression type, T_ScalarArrayOpExpr");
+		return false;
 #if PG_VERSION_NUM < 120000
-		case T_ArrayRef:
-			elog(NOTICE, "unsupported OGR FDW expression type, T_ArrayRef");
-			return false;
+	case T_ArrayRef:
+		elog(NOTICE, "unsupported OGR FDW expression type, T_ArrayRef");
+		return false;
 #else
-		case T_SubscriptingRef:
-			elog(NOTICE, "unsupported OGR FDW expression type, T_SubscriptingRef");
-			return false;
+	case T_SubscriptingRef:
+		elog(NOTICE, "unsupported OGR FDW expression type, T_SubscriptingRef");
+		return false;
 #endif
-		case T_ArrayExpr:
-			elog(NOTICE, "unsupported OGR FDW expression type, T_ArrayExpr");
-			return false;
-		case T_FuncExpr:
-			elog(NOTICE, "unsupported OGR FDW expression type, T_FuncExpr");
-			return false;
-		case T_DistinctExpr:
-			elog(NOTICE, "unsupported OGR FDW expression type, T_DistinctExpr");
-			return false;
-		default:
-			elog(NOTICE, "unsupported OGR FDW expression type for deparse: %d", (int) nodeTag(node));
-			return false;
+	case T_ArrayExpr:
+		elog(NOTICE, "unsupported OGR FDW expression type, T_ArrayExpr");
+		return false;
+	case T_FuncExpr:
+		elog(NOTICE, "unsupported OGR FDW expression type, T_FuncExpr");
+		return false;
+	case T_DistinctExpr:
+		elog(NOTICE, "unsupported OGR FDW expression type, T_DistinctExpr");
+		return false;
+	default:
+		elog(NOTICE, "unsupported OGR FDW expression type for deparse: %d", (int) nodeTag(node));
+		return false;
 	}
 
 }
 
 
 bool
-ogrDeparse(StringInfo buf, PlannerInfo *root, RelOptInfo *foreignrel, List *exprs, OgrFdwState *state, List **params)
+ogrDeparse(StringInfo buf, PlannerInfo* root, RelOptInfo* foreignrel, List* exprs, OgrFdwState* state, List** params)
 {
 	OgrDeparseCtx context;
-	ListCell *lc;
+	ListCell* lc;
 	bool first = true;
 
 	/* initialize result list to empty */
 	if (params)
+	{
 		*params = NIL;
+	}
 
 	/* Set up context struct for recursion */
 	context.buf = buf;
@@ -566,14 +618,14 @@ ogrDeparse(StringInfo buf, PlannerInfo *root, RelOptInfo *foreignrel, List *expr
 	// context.geom_op = NULL;
 	// context.geom_func = NULL;
 
-	foreach(lc, exprs)
+	foreach (lc, exprs)
 	{
-		RestrictInfo *ri = (RestrictInfo *) lfirst(lc);
+		RestrictInfo* ri = (RestrictInfo*) lfirst(lc);
 		int len_save = buf->len;
 		bool result;
 
 		/* Connect expressions with "AND" and parenthesize each condition */
-		if ( ! first )
+		if (! first)
 		{
 			appendStringInfoString(buf, " AND ");
 		}
@@ -583,15 +635,17 @@ ogrDeparse(StringInfo buf, PlannerInfo *root, RelOptInfo *foreignrel, List *expr
 		result = ogrDeparseExpr(ri->clause, &context);
 		// appendStringInfoChar(buf, ')');
 
-		if ( ! result )
+		if (! result)
 		{
 			/* Couldn't unparse some portion of the expression, so rewind the stringinfo */
 			setStringInfoLength(buf, len_save);
 		}
 
 		/* Don't flip the "first" bit until we get a good expression */
-		if ( first && result )
+		if (first && result)
+		{
 			first = false;
+		}
 	}
 
 	return true;
