@@ -19,18 +19,18 @@
 #include "ogr_fdw_common.h"
 
 static void usage();
-static OGRErr ogrListLayers(const char *source);
-static OGRErr ogrGenerateSQL(const char *source, const char *layer);
+static OGRErr ogrListLayers(const char* source);
+static OGRErr ogrGenerateSQL(const char* source, const char* layer);
 
 #define STR_MAX_LEN 256
 
 
 /* Define this no-op here, so that code */
 /* in the ogr_fdw_common module works */
-const char * quote_identifier(const char *ident);
+const char* quote_identifier(const char* ident);
 
-const char *
-quote_identifier(const char *ident)
+const char*
+quote_identifier(const char* ident)
 {
 	return ident;
 }
@@ -43,13 +43,13 @@ formats()
 
 	GDALAllRegister();
 
-	printf( "Supported Formats:\n" );
-	for ( i = 0; i < GDALGetDriverCount(); i++ )
+	printf("Supported Formats:\n");
+	for (i = 0; i < GDALGetDriverCount(); i++)
 	{
 		GDALDriverH ogr_dr = GDALGetDriver(i);
 		int vector = FALSE;
 		int createable = TRUE;
-		const char *tmpl;
+		const char* tmpl;
 
 #if GDAL_VERSION_MAJOR >= 2
 		char** papszMD = GDALGetMetadata(ogr_dr, NULL);
@@ -59,13 +59,20 @@ formats()
 		createable = GDALDatasetTestCapability(ogr_dr, ODrCCreateDataSource);
 #endif
 		/* Skip raster data sources */
-		if ( ! vector ) continue;
+		if (! vector)
+		{
+			continue;
+		}
 
 		/* Report sources w/ create capability as r/w */
-		if( createable )
+		if (createable)
+		{
 			tmpl = "  -> \"%s\" (read/write)\n";
+		}
 		else
+		{
 			tmpl = "  -> \"%s\" (readonly)\n";
+		}
 
 		printf(tmpl, GDALGetDriverShortName(ogr_dr));
 	}
@@ -77,57 +84,61 @@ static void
 usage()
 {
 	printf(
-		"usage: ogr_fdw_info -s <ogr datasource> -l <ogr layer>\n"
-		"	   ogr_fdw_info -s <ogr datasource>\n"
-		"	   ogr_fdw_info -f\n"
-		"\n");
+	    "usage: ogr_fdw_info -s <ogr datasource> -l <ogr layer>\n"
+	    "	   ogr_fdw_info -s <ogr datasource>\n"
+	    "	   ogr_fdw_info -f\n"
+	    "\n");
 	exit(0);
 }
 
 int
-main (int argc, char **argv)
+main(int argc, char** argv)
 {
 	int ch;
-	char *source = NULL, *layer = NULL;
+	char* source = NULL, *layer = NULL;
 	OGRErr err = OGRERR_NONE;
 
 	/* If no options are specified, display usage */
 	if (argc == 1)
+	{
 		usage();
+	}
 
-	while ((ch = getopt(argc, argv, "h?s:l:f")) != -1) {
-		switch (ch) {
-			case 's':
-				source = optarg;
-				break;
-			case 'l':
-				layer = optarg;
-				break;
-			case 'f':
-				formats();
-				break;
-			case '?':
-			case 'h':
-			default:
-				usage();
-				break;
+	while ((ch = getopt(argc, argv, "h?s:l:f")) != -1)
+	{
+		switch (ch)
+		{
+		case 's':
+			source = optarg;
+			break;
+		case 'l':
+			layer = optarg;
+			break;
+		case 'f':
+			formats();
+			break;
+		case '?':
+		case 'h':
+		default:
+			usage();
+			break;
 		}
 	}
 
-	if ( source && ! layer )
+	if (source && ! layer)
 	{
 		err = ogrListLayers(source);
 	}
-	else if ( source && layer )
+	else if (source && layer)
 	{
 		err = ogrGenerateSQL(source, layer);
 	}
-	else if ( ! source && ! layer )
+	else if (! source && ! layer)
 	{
 		usage();
 	}
 
-	if ( err != OGRERR_NONE )
+	if (err != OGRERR_NONE)
 	{
 		// printf("OGR Error: %s\n\n", CPLGetLastErrorMsg());
 	}
@@ -137,7 +148,7 @@ main (int argc, char **argv)
 }
 
 static OGRErr
-ogrListLayers(const char *source)
+ogrListLayers(const char* source)
 {
 	GDALDatasetH ogr_ds = NULL;
 	int i;
@@ -148,21 +159,21 @@ ogrListLayers(const char *source)
 	ogr_ds = OGROpen(source, FALSE, NULL);
 #else
 	ogr_ds = GDALOpenEx(source,
-						GDAL_OF_VECTOR|GDAL_OF_READONLY,
-						NULL, NULL, NULL);
+	                    GDAL_OF_VECTOR | GDAL_OF_READONLY,
+	                    NULL, NULL, NULL);
 #endif
 
-	if ( ! ogr_ds )
+	if (! ogr_ds)
 	{
 		CPLError(CE_Failure, CPLE_AppDefined, "Could not connect to source '%s'", source);
 		return OGRERR_FAILURE;
 	}
 
 	printf("Layers:\n");
-	for ( i = 0; i < GDALDatasetGetLayerCount(ogr_ds); i++ )
+	for (i = 0; i < GDALDatasetGetLayerCount(ogr_ds); i++)
 	{
 		OGRLayerH ogr_lyr = GDALDatasetGetLayer(ogr_ds, i);
-		if ( ! ogr_lyr )
+		if (! ogr_lyr)
 		{
 			return OGRERR_FAILURE;
 		}
@@ -176,7 +187,7 @@ ogrListLayers(const char *source)
 }
 
 static OGRErr
-ogrGenerateSQL(const char *source, const char *layer)
+ogrGenerateSQL(const char* source, const char* layer)
 {
 	OGRErr err;
 	GDALDatasetH ogr_ds = NULL;
@@ -191,24 +202,26 @@ ogrGenerateSQL(const char *source, const char *layer)
 	ogr_ds = OGROpen(source, FALSE, &ogr_dr);
 #else
 	ogr_ds = GDALOpenEx(source,
-						GDAL_OF_VECTOR|GDAL_OF_READONLY,
-						NULL, NULL, NULL);
+	                    GDAL_OF_VECTOR | GDAL_OF_READONLY,
+	                    NULL, NULL, NULL);
 #endif
 
-	if ( ! ogr_ds )
+	if (! ogr_ds)
 	{
 		CPLError(CE_Failure, CPLE_AppDefined, "Could not connect to source '%s'", source);
 		return OGRERR_FAILURE;
 	}
 
-	if ( ! ogr_dr )
+	if (! ogr_dr)
+	{
 		ogr_dr = GDALGetDatasetDriver(ogr_ds);
+	}
 
 	/* There should be a nicer way to do this */
 	strcpy(server_name, "myserver");
 
 	ogr_lyr = GDALDatasetGetLayerByName(ogr_ds, layer);
-	if ( ! ogr_lyr )
+	if (! ogr_lyr)
 	{
 		CPLError(CE_Failure, CPLE_AppDefined, "Could not find layer '%s' in source '%s'", layer, source);
 		return OGRERR_FAILURE;
@@ -216,23 +229,23 @@ ogrGenerateSQL(const char *source, const char *layer)
 
 	/* Output SERVER definition */
 	printf("\nCREATE SERVER %s\n"
-		"  FOREIGN DATA WRAPPER ogr_fdw\n"
-		"  OPTIONS (\n"
-		"	datasource '%s',\n"
-		"	format '%s' );\n",
-		server_name, source, GDALGetDriverShortName(ogr_dr));
+	       "  FOREIGN DATA WRAPPER ogr_fdw\n"
+	       "  OPTIONS (\n"
+	       "	datasource '%s',\n"
+	       "	format '%s' );\n",
+	       server_name, source, GDALGetDriverShortName(ogr_dr));
 
 	stringbuffer_init(&buf);
 	err = ogrLayerToSQL(ogr_lyr,
-			server_name,
-			TRUE, /* launder table names */
-			TRUE, /* launder column names */
-			TRUE, /* use postgis geometry */
-			&buf);
+	                    server_name,
+	                    TRUE, /* launder table names */
+	                    TRUE, /* launder column names */
+	                    TRUE, /* use postgis geometry */
+	                    &buf);
 
 	GDALClose(ogr_ds);
 
-	if ( err != OGRERR_NONE )
+	if (err != OGRERR_NONE)
 	{
 		return err;
 	}
